@@ -26,6 +26,9 @@ class ShopBase(models.Model):
         shopify_domain = self.shopify_domain
         return Session.temp(shopify_domain, api_version, self.shopify_token)
 
+    def installed(self):
+        pass
+
     def update_webhooks(self):
         update_shop_webhooks(self)
 
