@@ -70,6 +70,10 @@ class EndTokenRequestView(View):
 
         Shop = get_shop_model()
         shop_record = Shop.objects.get_or_create(shopify_domain=session.url)[0]
+
+        if not shop_record.access_token and access_token:
+            shop_record.installed()
+
         shop_record.shopify_token = access_token
         shop_record.access_scopes = session.access_scopes
 
